indexStore.SrbBdbIndexStore

|  | ## Cheshire3 Object Model: Class SrbBdbIndexStore

Module indexStore :: Class SrbBdbIndexStore

## Class SrbBdbIndexStore
source code

Object Tree:

               object --+
                        |
    configParser.C3Object --+
                            |
       baseObjects.IndexStore --+
                                |
                    BdbIndexStore --+
                                    |
                                   SrbBdbIndexStore

Instance Methods

_connect(self)
__init__(self, session, config, parent)
_openIndexChunk(self, session, index, chunk)
_createIndexChunk(self, session, index, chunk)
_storeIndexChunk(self, session, index, chunk)
_whichChunk(self, term)
_maybeFetchChunk(self, session, index, term)
_fetchChunk(self, session, index, chunk)
begin_indexing(self, session, index)
commit_indexing(self, session, index)
commit_indexing2(self, session, index, sorted)
create_index(self, session, index)
clean_index(self, session, index)
delete_index(self, session, index)
fetch_sortValue(self, session, index, item)
delete_terms(self, session, index, terms, record)
store_terms(self, session, index, hash, record)
fetch_termList(self, session, index, term, numReq=0, relation="", end="", summary=0, reverse=0)
fetch_term(self, session, index, term)
fetch_packed(self, session, index, term)
Inherited from `BdbIndexStore`: `contains_index`, `create_item`, `create_term`, `fetch_indexList`, `fetch_indexStats`, `fetch_temp_file`, `get_indexingPosition` Inherited from `BdbIndexStore` (private): `_closeIndex`, `_fileFilter`, `_generateFilename`, `_get_externalId`, `_get_internalId`, `_openIndex` Inherited from `configParser.C3Object`: `auth_function`, `get_config`, `get_default`, `get_object`, `get_path`, `get_setting`, `log_function`, `unauth_function`, `unlog_function` Inherited from `configParser.C3Object` (private): `_getDomFromFile`, `_handleConfigNode`, `_parseIncludes`, `_recurseSubConfigs`, `_verifyDefault`, `_verifyOption`, `_verifySetting` Inherited from `object`: `__delattr__`, `__getattribute__`, `__hash__`, `__new__`, `__reduce__`, `__reduce_ex__`, `__repr__`, `__setattr__`, `__str__`

Class Variables

host |
port |
user |
passwd |
dn |
domain |
resource |
subcollection |
connection |
tempChunks |
Inherited from `BdbIndexStore`: `identifierMapCxn`, `indexCxn`, `indexing`, `outFiles`, `outSortFiles`, `reservedLongs`, `sortStoreCxn`, `storeHash`, `storeHashReverse` Inherited from `configParser.C3Object`: `configStore`, `defaults`, `functionLogger`, `id`, `name`, `objectType`, `objects`, `parent`, `paths`, `permissionHandlers`, `settings`, `subConfigs`, `unresolvedObjects` Inherited from `configParser.C3Object` (private): `_includeConfigStores`, `_objectRefs` Inherited from `object`: `__class__`

Method Details

### _connect(self) | source code

### __init__(self, session, config, parent) (Constructor) | source code
Overrides: BdbIndexStore.__init__

### _openIndexChunk(self, session, index, chunk) | source code

### _createIndexChunk(self, session, index, chunk) | source code

### _storeIndexChunk(self, session, index, chunk) | source code

### _whichChunk(self, term) | source code

### _maybeFetchChunk(self, session, index, term) | source code

### _fetchChunk(self, session, index, chunk) | source code

### begin_indexing(self, session, index) | source code
Overrides: BdbIndexStore.begin_indexing

### commit_indexing(self, session, index) | source code
Overrides: BdbIndexStore.commit_indexing

### commit_indexing2(self, session, index, sorted) | source code
Overrides: BdbIndexStore.commit_indexing2

### create_index(self, session, index) | source code
Overrides: BdbIndexStore.create_index

### clean_index(self, session, index) | source code
Overrides: BdbIndexStore.clean_index

### delete_index(self, session, index) | source code
Overrides: BdbIndexStore.delete_index

### fetch_sortValue(self, session, index, item) | source code
Overrides: BdbIndexStore.fetch_sortValue

### delete_terms(self, session, index, terms, record) | source code
Overrides: BdbIndexStore.delete_terms

### store_terms(self, session, index, hash, record) | source code
Overrides: BdbIndexStore.store_terms

### fetch_termList(self, session, index, term, numReq=0, relation="", end="", summary=0, reverse=0) | source code
Overrides: BdbIndexStore.fetch_termList

### fetch_term(self, session, index, term) | source code
Overrides: BdbIndexStore.fetch_term

### fetch_packed(self, session, index, term) | source code
Overrides: BdbIndexStore.fetch_packed

Class Variable Details

    ### host Value:
        ""

    ### port Value:
        ""

    ### user Value:
        ""

    ### passwd Value:
        ""

    ### dn Value:
        ""

    ### domain Value:
        ""

    ### resource Value:
        ""

    ### subcollection Value:
        ""

    ### connection Value:
        None

    ### tempChunks Value:
        0